Algorithm

Trait Algorithm 

pub trait Algorithm {
    const ALG_NAME: &'static str;
    const MAX_SECURITY_STRENGTH: SecurityStrength;
}
Metadata about a cryptographic algorithm.

Required Associated Constants

const ALG_NAME: &'static str

String name for the algorithm, used consistently across the library.

const MAX_SECURITY_STRENGTH: SecurityStrength

Maximum security strength supported by the algorithm. In other words, this algorithm can produce outputs up to this security strength, but may produce outputs with lower security strength, for example, if asked to truncate.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors