HashAlgParams

Trait HashAlgParams 

pub trait HashAlgParams: Algorithm {
    const OUTPUT_LEN: usize;
    const BLOCK_LEN: usize;
}
Standard parameters for a hash function.

Required Associated Constants

const OUTPUT_LEN: usize

The fixed output length of the hash function.

const BLOCK_LEN: usize

The internal block length of the hash function, which is often used as a meta-parameter for determining the security strength of the hash function since this limits the internal collision resistance of the hash function.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors