Secret

Trait Secret 

pub trait Secret:
    Drop
    + Debug
    + Display { }
A trait that forces an object to implement a zeroizing Drop() as well as Debug and Display that will not log the sensitive contents, even in error or crash-dump scenarios.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<const KEY_LEN: usize> Secret for KeyMaterial<KEY_LEN>